Index
$#! · 0-9 · A · B · C · D · E · F · G · H · I · J · K · L · M · N · O · P · Q · R · S · T · U · V · W · X · Y · Z

I |
| index, Series
| init, jqPlot
| innerDiameter, $.jqplot.DonutRenderer
| insertBreaks, $.jqplot.BlockRenderer
| intersectionThreshold, $.jqplot.Cursor
| interval, $.jqplot.LineRenderer
| intervalColors, $.jqplot.MeterGaugeRenderer
| intervalInnerRadius, $.jqplot.MeterGaugeRenderer
| intervalOuterRadius, $.jqplot.MeterGaugeRenderer
| intervals, $.jqplot.MeterGaugeRenderer
| Introduction
| isarc $.jqplot.shadowRenderer$.jqplot.shapeRenderer
| isMinorTick $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer
J |
| jqPlot
| jqPlot Charts
| jqPlot CSS Customization
| jqPlot Options
| jqPlot Pugin Hooks, $.jqplot
| jqPlot Usage
| jqplot.enhancedLegendRenderer.js
| jqplot.pyramidAxisRenderer.js
| jqplot.pyramidRenderer.js
L |
| label $.jqplot.AxisLabelRenderer$.jqplot.CanvasAxisLabelRenderer$.jqplot.MeterGaugeRenderer$.jqplot.Trendline Axis Series
| labelHeightAdjust, $.jqplot.MeterGaugeRenderer
| labelOptions, Axis
| labelPosition $.jqplot.CanvasAxisTickRenderer$.jqplot.MeterGaugeRenderer
| labelRenderer, Axis
| labels $.jqplot.PointLabels Legend
| labelsFromSeries, $.jqplot.PointLabels
| legend, jqPlot
| Legend
| Line
| lineCap $.jqplot.CanvasOverlay$.jqplot.shadowRenderer$.jqplot.shapeRenderer Series
| lineJoin $.jqplot.shadowRenderer$.jqplot.shapeRenderer Series
| linePattern $.jqplot.shapeRenderer Series
| lineWidth $.jqplot.CanvasOverlay$.jqplot.FunnelRenderer$.jqplot.MarkerRenderer$.jqplot.OHLCRenderer$.jqplot.shadowRenderer$.jqplot.Trendline Series
| lineWidthAdjust, $.jqplot.Highlighter
| location $.jqplot.PointLabels Legend
| looseZoom, $.jqplot.Cursor
M |
| makeGridData $.jqplot.BezierCurveRenderer.js$.jqplot.MekkoRenderer
| marginBottom, Legend
| marginLeft, Legend
| marginRight, Legend
| marginTop, Legend
| mark $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer
| markerOptions, Series
| markerRenderer $.jqplot.Highlighter$.jqplot.Trendline Series
| markSize $.jqplot.AxisTickRenderer$.jqplot.CanvasAxisTickRenderer
| max $.jqplot.MeterGaugeRenderer Axis
| methods $.jqplot.Cursor$.jqplot.ThemeEngine jqPlot
| Methods, $.jqplot.BlockRenderer
| min $.jqplot.MeterGaugeRenderer Axis
| minorTicks $.jqplot.LinearAxisRenderer$.jqplot.LogAxisRenderer
| MIT License
| moveBlock, $.jqplot.BlockRenderer
| moveSeriesToBack, jqPlot
| moveSeriesToFront, jqPlot

> this.index

0 based index of this series in the plot series array.

> this.init = function( | target,
> | data,
> | options | )

sets the plot target, checks data and applies user options to plot.

> this.innerDiameter = null

Inner diameter of the donut, auto calculated by default.

> this.insertBreaks = true

true to turn spaces in data block label into html breaks br /.

> this.intersectionThreshold = 2

pixel distance from data point or marker to consider cursor lines intersecting with point.

> interval: '3%' }

User specified interval above and below line for bands [default: ‘3%’’].

> this.intervalColors = [ "#4bb2c5", "#EAA228", "#c5b47f", "#579575", "#839557", "#958c12", "#953579", "#4b5de4", "#d8b83f", "#ff5800", "#0085cc", "#c747a3", "#cddf54", "#FBD178", "#26B4E3", "#bd70c7"]

Array of colors to use for the intervals.

> this.intervalInnerRadius = null

Radius of the inner circle of the interval ring.

> this.intervalOuterRadius = null

Radius of the outer circle of the interval ring.

> this.intervals = []

Array of ranges to be drawn around the gauge.
jqPlot requires jQuery (1.4+ required for certain features).

> this.isarc = false

whether the shadow is an arc or not.

> this.isarc = false

whether the shadow is an arc or not.

> this.isMinorTick = false

if this is a minor tick.

> this.isMinorTick = false

if this is a minor tick.
Plot object returned by call to $.jqplot.
Pure JavaScript plotting plugin for jQuery.
Much of the styling of jqPlot is done by css.
This document is out of date.

> this.label = ''

The text or html for the label.

> this.label = ''

label for the axis.

> this.label = null

A gauge label like ‘kph’ or ‘Volts’

> this.label = ''

Label for the trend line to use in the legend.

> this.label = null

Label for the axis

> this.label = ''

Line label to use in the legend.

> this.labelHeightAdjust = 0

Number of Pixels to offset the label up (-) or down (+) from its default position.

> this.labelOptions = {}

Options passed to the label renderer.

> this.labelPosition = 'auto'

‘auto’, ‘start’, ‘middle’ or ‘end’.

> this.labelPosition = 'inside'

Where to position the label, either ‘inside’ or ‘bottom’.

> this.labelRenderer = $.jqplot.AxisLabelRenderer

A class of a rendering engine for creating an axis label.

> this.labels = []

array of arrays of labels, one array for each series.

> this.labels = []

Array of labels to use.

> this.labelsFromSeries = false

true to use labels within data point arrays.

> this.legend = new Legend()

see $.jqplot.TableLegendRenderer
Legend object.
A straight line.
Type of ending placed on the line [‘round’, ‘butt’, ‘square’]

> this.lineCap = 'round'

how ends of the shadow line are rendered.

> this.lineCap = 'round'

how ends of the shadow line are rendered.

> this.lineCap = 'round'

Canvas lineCap style at ends of line.

> this.lineJoin = 'miter'

How line segments of the shadow are joined.

> this.lineJoin = 'miter'

How line segments of the shadow are joined.

> this.lineJoin = 'round'

Canvas lineJoin style between segments of series.

> this.linePattern = 'solid'

line pattern ‘dashed’, ‘dotted’, ‘solid’, some combination of ‘-’ and ‘.’

> this.linePattern = 'solid'

line pattern ‘dashed’, ‘dotted’, ‘solid’, some combination of ‘-’ and ‘.’
Width of the line.

> this.lineWidth = 2

width of line if areas are stroked and not filled.

> this.lineWidth = 2

size of the line for non-filled markers.

> this.lineWidth = 1.5

Width of the hi-low line and open/close ticks.

> this.lineWidth = 1.5

width of the shadow line stroke.

> this.lineWidth = 1.5

Width of the trend line.

> this.lineWidth = 2.5

width of the line in pixels.

> this.lineWidthAdjust = 2.5

Pixels to add to the lineWidth of the highlight.

> this.location = 'n'

compass location where to position the label around the point.

> this.location = 'ne'

Placement of the legend.

> this.looseZoom = true

Will expand zoom range to provide more rounded tick values.

> $.jqplot.BezierCurveRenderer.prototype.makeGridData = function( | data,
> | plot | )

converts any arbitrary data values to grid coordinates and returns them.

> $.jqplot.MekkoRenderer.prototype.makeGridData = function( | data,
> | plot | )

converts any arbitrary data values to grid coordinates and returns them.

> this.marginBottom = null

CSS margin for the legend DOM element.

> this.marginLeft = null

CSS margin for the legend DOM element.

> this.marginRight = null

CSS margin for the legend DOM element.

> this.marginTop = null

CSS margin for the legend DOM element.

> this.mark = 'outside'

tick mark on the axis.

> this.mark = 'outside'

tick mark on the axis.

> this.markerOptions = {}

renderer specific options to pass to the markerRenderer, see $.jqplot.MarkerRenderer.

> this.markerRenderer = new $.jqplot.MarkerRenderer( | {shadow:false} | )

Renderer used to draw the marker of the highlighted point.

> this.markerRenderer = {show:false}

Renderer to use to draw markers on the line.

> this.markerRenderer = $.jqplot.MarkerRenderer

A class of a renderer which will draw marker (e.g.

> this.markSize = 6

Length of the tick marks in pixels.

> this.markSize = 4

Length of the tick marks in pixels.

> this.max

Maximum value on the gauge.

> this.max = null

maximum value of the axis (in data units, not pixels).

> this.min

Minimum value on the gauge.

> this.min = null

minimum value of the axis (in data units, not pixels).

> this.minorTicks = 0

Number of ticks to add between “major” ticks.

> this.minorTicks = 'auto'

Number of ticks to add between “major” ticks.
Copyright © 2009-2013 Chris Leonello

> this.moveBlock = function ( | idx,
> | x,
> | y,
> | duration | )

Moves an individual block.

> this.moveSeriesToBack = function ( | idx | )

This method requires jQuery 1.4+ Moves the specified series canvas behind all other series canvases.

> this.moveSeriesToFront = function ( | idx | )

This method requires jQuery 1.4+ Moves the specified series canvas in front of all other series canvases.
Close